==> coturn-4.6.3.tar.gz: coturn-4.6.3/docker/coturn/CHANGELOG.md <==
Coturn TURN server Docker image changelog
=========================================




## [4.6.2-r13] · 2024-12-06
[4.6.2-r13]: /../../tree/4.6.2-r13

### Upgraded

- [Alpine Linux] 3.21: <https://alpinelinux.org/posts/Alpine-3.21.0-released.html>

### Security updated

- [Debian Linux] "bookworm" 20241202 (12.8): <https://github.com/docker-library/official-images/commit/36ffb3d236c35c22922dfeca1844d7ad119b06f5>




## [4.6.2-r12] · 2024-09-09
[4.6.2-r12]: /../../tree/docker/4.6.2-r12

### Security updated

- [Alpine Linux] 3.20.3: <https://github.com/docker-library/official-images/commit/94a433c3550a63993b4d7a2081ae87dfe1f7f6bf>
- [Debian Linux] "bookworm" 20240904 (12.7): <https://github.com/docker-library/official-images/commit/c8fa319f742b43465f60dda8d67cdc8d66eb615d>




## [4.6.2-r11] · 2024-07-26
[4.6.2-r11]: /../../tree/docker/4.6.2-r11

### Security updated

- [Alpine Linux] 3.20.2: <https://github.com/docker-library/official-images/commit/1a994d381a873e6f9579843dd1eebf64bc50e831>
- [Debian Linux] "bookworm" 20240722 (12.6): <https://github.com/docker-library/official-images/commit/62a03fd2a8fd79c245b11fb01e3e9d1be4214566>




## [4.6.2-r10] · 2024-06-21
[4.6.2-r10]: /../../tree/docker/4.6.2-r10

### Security updated

- [Alpine Linux] 3.20.1: <https://github.com/docker-library/official-images/commit/9434c6383adc38dd26c6c1b098bed1981a6d9e7f>
- [Debian Linux] "bookworm" 20240612 (12.5): <https://github.com/docker-library/official-images/commit/5891883bb94aefbf0ec4fa1fea1bc4679d164657>




## [4.6.2-r9] · 2024-05-24
[4.6.2-r9]: /../../tree/docker/4.6.2-r9

### Upgraded

- [Alpine Linux] 3.20: <https://alpinelinux.org/posts/Alpine-3.20.0-released.html>

### Security updated

- [Debian Linux] "bookworm" 20240513 (12.5): <https://github.com/docker-library/official-images/commit/d83cd3afd0e94fbf9a7ef07bdc84ac2b4a492e91>




## [4.6.2-r8] · 2024-01-29
[4.6.2-r8]: /../../tree/docker/4.6.2-r8

### Security updated

- [Alpine Linux] 3.19.1: <https://github.com/docker-library/official-images/commit/a5a02e00e489cfaa9dc8056755cd00abe7d0f646>
- [Debian Linux] "bookworm" 20240110 (12.4): <https://github.com/docker-library/official-images/commit/06237a1cf18ad130b442a864854804c1a534ff29>




## [4.6.2-r7] · 2023-12-08
[4.6.2-r7]: /../../tree/docker/4.6.2-r7

### Upgraded

- [Alpine Linux] 3.19: <https://alpinelinux.org/posts/Alpine-3.19.0-released.html>




## [4.6.2-r6] · 2023-12-01
[4.6.2-r6]: /../../tree/docker/4.6.2-r6

### Security updated

- [Alpine Linux] 3.18.5: <https://github.com/docker-library/official-images/commit/7e13453ce3b47c537e4ffe79127d4900825e9d03>
- [Debian Linux] "bookworm" 20231120: <https://github.com/docker-library/official-images/commit/bc9070c6b145c707a27d9e5c7db792139e36c2b6>




## [4.6.2-r5] · 2023-10-05
[4.6.2-r5]: /../../tree/docker/4.6.2-r5

### Security updated

- [Alpine Linux] 3.18.4: <https://github.com/docker-library/official-images/commit/2f22914dcf488bd066771452d2c694ad4f7e88c4>
- [Debian Linux] "bookworm" 20230919: <https://github.com/docker-library/official-images/commit/8b469263a1fab3a17b9f520bcf8ef53f3c828e27>




## [4.6.2-r4] · 2023-07-04
[4.6.2-r4]: /../../tree/docker/4.6.2-r4

### Added

- Additional tags with major OS version. ([#1230], [#1226])

### Security updated

- [Debian Linux] "bookworm" 20230703: <https://github.com/docker-library/official-images/commit/e4358612aca01fd8aa393e7b3d590d45ae72e9af>

[#1226]: /../../issues/1226
[#1230]: /../../pull/1230




## [4.6.2-r3] · 2023-06-15
[4.6.2-r3]: /../../tree/docker/4.6.2-r3

### Security updated

- [Alpine Linux] 3.18.2: <https://github.com/docker-library/official-images/commit/b187a3b64f4b23f4de4aef23b98cef0a128aa8f1>




## [4.6.2-r2] · 2023-06-13
[4.6.2-r2]: /../../tree/docker/4.6.2-r2

### Upgraded

- [Debian Linux] "bookworm": <https://www.debian.org/releases/bookworm>




## [4.6.2-r1] · 2023-05-10
[4.6.2-r1]: /../../tree/docker/4.6.2-r1

### Upgraded

- [Alpine Linux] 3.18: <https://alpinelinux.org/posts/Alpine-3.18.0-released.html>

### Security updated

- [Debian Linux] "bullseye" 20230502: <https://github.com/docker-library/official-images/commit/e4358612aca01fd8aa393e7b3d590d45ae72e9af>




## [4.6.2-r0] · 2023-04-12
[4.6.2-r0]: /../../tree/docker/4.6.2-r0

### Upgraded

- [Coturn] 4.6.2: <https://github.com/coturn/coturn/blob/4.6.2/ChangeLog>
- [Alpine Linux] 3.17: <https://alpinelinux.org/posts/Alpine-3.17.0-released.html>

### Security updated

- [Debian Linux] "bullseye" 20230411: <https://github.com/docker-library/official-images/commit/7697552ea03fcfa76ac2482c8a8ccfb2b594d545>




## [4.6.1-r3] · 2023-03-31
[4.6.1-r3]: /../../tree/docker/4.6.1-r3

### Security updated

- [Alpine Linux] 3.16.5: <https://github.com/docker-library/official-images/commit/d5e1db947991b391f375ef1e8686b884538c1917>
- [Debian Linux] "bullseye" 20230320: <https://github.com/docker-library/official-images/commit/066bc3b863f98325ff211a27301fe1b5a5d51721>




## [4.6.1-r2] · 2023-02-13
[4.6.1-r2]: /../../tree/docker/4.6.1-r2

### Security updated

- [Alpine Linux] 3.16.4: <https://github.com/docker-library/official-images/commit/5819aa56167e9874ef65e35da8277dc71b3ecee6>
- [Debian Linux] "bullseye" 20230208: <https://github.com/docker-library/official-images/commit/0a379d1f4d38dee47df84b07afcf5c26d03cc5a5>




## [4.6.1-r1] · 2023-01-31
[4.6.1-r1]: /../../tree/docker/4.6.1-r1

### Fixed

- Incorrect argument expansion in `docker-entrypoint.sh`. ([#1110])

### Security updated

- [Debian Linux] "bullseye" 20230109: <https://github.com/docker-library/official-images/commit/5e4784af91b60ebae23aab567b6cea3dcdb173a0>

[#1110]: /../../pull/1110




## [4.6.1-r0] · 2022-12-04
[4.6.1-r0]: /../../tree/docker/4.6.1-r0

### Upgraded

- [Coturn] 4.6.1: <https://github.com/coturn/coturn/blob/491b231f80471e63d3f5f3e967a9367e508b2da5/ChangeLog>




## [4.6.0-r1] · 2022-11-16
[4.6.0-r1]: /../../tree/docker/4.6.0-r1

### Added

- Support of `linux/386` platform.

### Security updated

- [Alpine Linux] 3.16.3: <https://github.com/docker-library/official-images/commit/bbdc5719dd50a7d4c112b517b5bd6d7f8d35ceff>
- [Debian Linux] "bullseye" 20221114: <https://github.com/docker-library/official-images/commit/629455d056a9b046c12d4fa65a1006d4b94b5fa5>




## [4.6.0-r0] · 2022-08-13
[4.6.0-r0]: /../../tree/docker/4.6.0-r0

### Upgraded

- [Coturn] 4.6.0: <https://github.com/coturn/coturn/blob/b7b43edd33c21caf18547243649272d2ada1d112/ChangeLog>

### Security updated

- [Debian Linux] "bullseye" 20220912: <https://github.com/docker-library/official-images/commit/80ce239c006d681e7687e1a73777126db94e9959>




## [4.5.2-r14] · 2022-08-10
[4.5.2-r14]: /../../tree/docker/4.5.2-r14

### Security updated

- [Alpine Linux] 3.16.2: <https://github.com/docker-library/official-images/commit/00214788d0150e2bcf2b2f51f786f92addef2478>
- [Debian Linux] "bullseye" 20220801: <https://github.com/docker-library/official-images/commit/ce10f6b60289c0c0b5de6f785528b8725f225a58>




## [4.5.2-r13] · 2022-07-19
[4.5.2-r13]: /../../tree/docker/4.5.2-r13

### Security updated

- [Alpine Linux] 3.16.1: <https://github.com/docker-library/official-images/commit/dcc1108c96213d2f8cca14c23273526913312146>
- [Debian Linux] "bullseye" 20220622: <https://github.com/docker-library/official-images/commit/979b8e278e5d921f1bfddf07d1ab56ab6bb9c3f9>




## [4.5.2-r12] · 2022-05-24
[4.5.2-r12]: /../../tree/docker/4.5.2-r12

### Upgraded

- [Alpine Linux] 3.16: <https://alpinelinux.org/posts/Alpine-3.16.0-released.html>

### Security updated

- [Debian Linux] "bullseye" 20220509: <https://github.com/docker-library/official-images/commit/5e2abb3fc26aa1e16e7e3516580621bef93a64e2>




## [4.5.2-r11] · 2022-04-06
[4.5.2-r11]: /../../tree/docker/4.5.2-r11

### Security updated

- [Alpine Linux] 3.15.4: <https://github.com/docker-library/official-images/commit/1c3c904f7310fa85d2efad018596cc040e00c018>




## [4.5.2-r10] · 2022-03-29
[4.5.2-r10]: /../../tree/docker/4.5.2-r10

### Security updated

- [Alpine Linux] 3.15.3: <https://github.com/docker-library/official-images/commit/e83c8d565978ce1edf1b7bb565484e8cb4419d24>
- [Debian Linux] "bullseye" 20220328: <https://github.com/docker-library/official-images/commit/805cd38af6aec5e5a475c0229c6c1c9831af6124>




## [4.5.2-r9] · 2022-03-25
[4.5.2-r9]: /../../tree/docker/4.5.2-r9

### Security updated

- [Alpine Linux] 3.15.2: <https://github.com/docker-library/official-images/commit/72599f4196000032663a637e542cd23b4dc68936>
- [Debian Linux] "bullseye" 20220316: <https://github.com/docker-library/official-images/commit/1e1bb99db26edc6b8605d83eefc22e1288203a20>




## [4.5.2-r8] · 2021-12-03
[4.5.2-r8]: /../../tree/docker/4.5.2-r8

### Added

- Default TLS ports. ([#860])

[#860]: /../../pull/860




## [4.5.2-r7] · 2021-11-25
[4.5.2-r7]: /../../tree/docker/4.5.2-r7

### Upgraded

- [Alpine Linux] 3.15: <https://alpinelinux.org/posts/Alpine-3.15.0-released.html>




## [4.5.2-r6] · 2021-11-15
[4.5.2-r6]: /../../tree/docker/4.5.2-r6

### Security updated

- [Alpine Linux] 3.14.3: <https://github.com/docker-library/official-images/commit/89298ea1c14b4241dcf3bad1b3092d178ca1ecbc>




## [4.5.2-r5] · 2021-08-29
[4.5.2-r5]: /../../tree/docker/4.5.2-r5

### Upgraded

- [Debian Linux] "bullseye": <https://www.debian.org/releases/bullseye/releasenotes>




## [4.5.2-r4] · 2021-08-28
[4.5.2-r4]: /../../tree/docker/4.5.2-r4

### Security updated

- [Alpine Linux] 3.14.2: <https://github.com/docker-library/official-images/commit/b54effe0cc65795f29752ecc197328a04326a6f2>




## [4.5.2-r3] · 2021-08-09
[4.5.2-r3]: /../../tree/docker/4.5.2-r3

### Security updated

- [Alpine Linux] 3.14.1: <https://github.com/docker-library/official-images/commit/a52e64df36ca65954c6c7f57ad242634e834c73a>




## [4.5.2-r2] · 2021-06-21
[4.5.2-r2]: /../../tree/docker/4.5.2-r2

### Upgraded

- [Alpine Linux] 3.14: <https://alpinelinux.org/posts/Alpine-3.14.0-released.html>




## [4.5.2-r1] · 2021-06-03
[4.5.2-r1]: /../../tree/docker/4.5.2-r1

### Added

- [Prometheus] support with [prometheus-client-c] 0.1.3: <https://github.com/digitalocean/prometheus-client-c/releases/tag/v0.1.3> ([#754])

### Improved

- Use DNS requests to discover external IP address in `detect-external-ip` script. ([#753])

### Fixed

- Incorrect linking with [mongo-c-driver] on [Debian Linux] image.

[#753]: /../../pull/753
[#754]: /../../pull/754




## [4.5.2-r0] · 2021-04-15
[4.5.2-r0]: /../../tree/docker/4.5.2-r0

### Created

- [Coturn] 4.5.2: <https://github.com/coturn/coturn/blob/upstream/4.5.2/ChangeLog> 
- [Alpine Linux] 3.13: <https://alpinelinux.org/posts/Alpine-3.13.0-released.html>
- [Debian Linux] "buster": <https://www.debian.org/releases/buster/releasenotes>
- [mongo-c-driver] 1.17.5 (`debian` only): <https://github.com/mongodb/mongo-c-driver/releases/tag/1.17.5>
- Supported platforms:
    - `linux/amd64`
    - `linux/arm64`
    - `linux/arm/v6`
    - `linux/arm/v7`
    - `linux/ppc64le`
    - `linux/s390x`




[Alpine Linux]: https://www.alpinelinux.org
[Coturn]: https://haraka.github.io
[Debian Linux]: https://www.debian.org
[mongo-c-driver]: https://github.com/mongodb/mongo-c-driver
[Prometheus]: https://prometheus.io
[prometheus-client-c]: https://github.com/digitalocean/prometheus-client-c

==> coturn-4.8.0.tar.gz: coturn-4.8.0/docker/coturn/CHANGELOG.md <==
Coturn TURN server Docker image changelog
=========================================




## [edge]
[edge]: /../../tree/master

### Security updated

- [Debian Linux] "trixie" 20251229 (13.2): <https://github.com/docker-library/official-images/commit/75258b45695c052980fce53c610b7ec5f700db87>




## [4.7.0-r4] · 2025-12-18
[4.7.0-r4]: /../../tree/docker/4.7.0-r4

### Security updated

- [Alpine Linux] 3.23.2: <https://github.com/docker-library/official-images/commit/3159434b3c3d42e64dcbc7364d0031abe92210a3>
- [Debian Linux] "trixie" 20251208 (13.2): <https://github.com/docker-library/official-images/commit/11670f6c414419f5eb6febb8a94978354073a016>




## [4.7.0-r3] · 2025-12-04
[4.7.0-r3]: /../../tree/docker/4.7.0-r3

### Upgraded

- [Alpine Linux] 3.23: <https://www.alpinelinux.org/posts/Alpine-3.23.0-released.html>

### Security updated

- [Debian Linux] "trixie" 20251117 (13.2): <https://github.com/docker-library/official-images/commit/215fa7075010e3f2da20008b1a3a223b788beb0d>




## [4.7.0-r2] · 2025-10-09
[4.7.0-r2]: /../../tree/docker/4.7.0-r2

### Security updated

- [Alpine Linux] 3.22.2: <https://github.com/docker-library/official-images/commit/fdacb511822ac9045ec7ec066c1228f94291139f>
- [Debian Linux] "trixie" 20250929 (13.1): <https://www.debian.org/releases/trixie>, <https://github.com/docker-library/official-images/commit/bb9759b29477674ff2e13518ec2de144fb863b35>




## [4.7.0-r1] · 2025-07-16
[4.7.0-r1]: /../../tree/docker/4.7.0-r1

### Security updated

- [Alpine Linux] 3.22.1: <https://github.com/docker-library/official-images/commit/9411795f2a8ba13baa3be3ca4a7827170a445695>
- [Debian Linux] "bookworm" 20250630 (12.11): <https://github.com/docker-library/official-images/commit/2568150630c10253d352ff0695b0dc73717230c1>




## [4.7.0-r0] · 2025-06-02
[4.7.0-r0]: /../../tree/docker/4.7.0-r0

### Upgraded

- [Coturn] 4.7.0: <https://github.com/coturn/coturn/blob/4.7.0/ChangeLog>
- [Alpine Linux] 3.22: <https://www.alpinelinux.org/posts/Alpine-3.22.0-released.html>

### Security updated

- [Debian Linux] "bookworm" 20250520 (12.11): <https://github.com/docker-library/official-images/commit/6d7afdaec5dec1a0b4021b4e470853c3e9fba2bc>




## [4.6.3-r3] · 2025-02-17
[4.6.3-r3]: /../../tree/docker/4.6.3-r3

### Security updated

- [Alpine Linux] 3.21.3: <https://github.com/docker-library/official-images/commit/a536b8d448389cbe8691ab77986e2cbaff01005f>
- [Debian Linux] "bookworm" 20250203 (12.9): <https://github.com/docker-library/official-images/commit/454b1e5e30feb21440c31c8c109cf4a6cc059d5e>




## [4.6.3-r2] · 2025-01-09
[4.6.3-r2]: /../../tree/docker/4.6.3-r2

### Security updated

- [Alpine Linux] 3.21.2: <https://github.com/docker-library/official-images/commit/824cefde693b820f783266fda449588ca583a1b0>




## [4.6.3-r1] · 2025-01-08
[4.6.3-r1]: /../../tree/docker/4.6.3-r1

### Security updated

- [Alpine Linux] 3.21.1: <https://github.com/docker-library/official-images/commit/34b47f1f4bdef69e39ae335e55b0f07af3b4fa18>
- [Debian Linux] "bookworm" 20241223 (12.8): <https://github.com/docker-library/official-images/commit/b6ea0fc48d92a7f6ef631667e82600666be53181>




## [4.6.3-r0] · 2024-12-11
[4.6.3-r0]: /../../tree/docker/4.6.3-r0

### Upgraded

- [Coturn] 4.6.3: <https://github.com/coturn/coturn/blob/4.6.3/ChangeLog>




## [4.6.2-r13] · 2024-12-06
[4.6.2-r13]: /../../tree/docker/4.6.2-r13

### Upgraded

- [Alpine Linux] 3.21: <https://alpinelinux.org/posts/Alpine-3.21.0-released.html>

### Security updated

- [Debian Linux] "bookworm" 20241202 (12.8): <https://github.com/docker-library/official-images/commit/36ffb3d236c35c22922dfeca1844d7ad119b06f5>




## [4.6.2-r12] · 2024-09-09
[4.6.2-r12]: /../../tree/docker/4.6.2-r12

### Security updated

- [Alpine Linux] 3.20.3: <https://github.com/docker-library/official-images/commit/94a433c3550a63993b4d7a2081ae87dfe1f7f6bf>
- [Debian Linux] "bookworm" 20240904 (12.7): <https://github.com/docker-library/official-images/commit/c8fa319f742b43465f60dda8d67cdc8d66eb615d>




## [4.6.2-r11] · 2024-07-26
[4.6.2-r11]: /../../tree/docker/4.6.2-r11

### Security updated

- [Alpine Linux] 3.20.2: <https://github.com/docker-library/official-images/commit/1a994d381a873e6f9579843dd1eebf64bc50e831>
- [Debian Linux] "bookworm" 20240722 (12.6): <https://github.com/docker-library/official-images/commit/62a03fd2a8fd79c245b11fb01e3e9d1be4214566>




## [4.6.2-r10] · 2024-06-21
[4.6.2-r10]: /../../tree/docker/4.6.2-r10

### Security updated

- [Alpine Linux] 3.20.1: <https://github.com/docker-library/official-images/commit/9434c6383adc38dd26c6c1b098bed1981a6d9e7f>
- [Debian Linux] "bookworm" 20240612 (12.5): <https://github.com/docker-library/official-images/commit/5891883bb94aefbf0ec4fa1fea1bc4679d164657>




## [4.6.2-r9] · 2024-05-24
[4.6.2-r9]: /../../tree/docker/4.6.2-r9

### Upgraded

- [Alpine Linux] 3.20: <https://alpinelinux.org/posts/Alpine-3.20.0-released.html>

### Security updated

- [Debian Linux] "bookworm" 20240513 (12.5): <https://github.com/docker-library/official-images/commit/d83cd3afd0e94fbf9a7ef07bdc84ac2b4a492e91>




## [4.6.2-r8] · 2024-01-29
[4.6.2-r8]: /../../tree/docker/4.6.2-r8

### Security updated

- [Alpine Linux] 3.19.1: <https://github.com/docker-library/official-images/commit/a5a02e00e489cfaa9dc8056755cd00abe7d0f646>
- [Debian Linux] "bookworm" 20240110 (12.4): <https://github.com/docker-library/official-images/commit/06237a1cf18ad130b442a864854804c1a534ff29>




## [4.6.2-r7] · 2023-12-08
[4.6.2-r7]: /../../tree/docker/4.6.2-r7

### Upgraded

- [Alpine Linux] 3.19: <https://alpinelinux.org/posts/Alpine-3.19.0-released.html>




## [4.6.2-r6] · 2023-12-01
[4.6.2-r6]: /../../tree/docker/4.6.2-r6

### Security updated

- [Alpine Linux] 3.18.5: <https://github.com/docker-library/official-images/commit/7e13453ce3b47c537e4ffe79127d4900825e9d03>
- [Debian Linux] "bookworm" 20231120: <https://github.com/docker-library/official-images/commit/bc9070c6b145c707a27d9e5c7db792139e36c2b6>




## [4.6.2-r5] · 2023-10-05
[4.6.2-r5]: /../../tree/docker/4.6.2-r5

### Security updated

- [Alpine Linux] 3.18.4: <https://github.com/docker-library/official-images/commit/2f22914dcf488bd066771452d2c694ad4f7e88c4>
- [Debian Linux] "bookworm" 20230919: <https://github.com/docker-library/official-images/commit/8b469263a1fab3a17b9f520bcf8ef53f3c828e27>




## [4.6.2-r4] · 2023-07-04
[4.6.2-r4]: /../../tree/docker/4.6.2-r4

### Added

- Additional tags with major OS version. ([#1230], [#1226])

### Security updated

- [Debian Linux] "bookworm" 20230703: <https://github.com/docker-library/official-images/commit/e4358612aca01fd8aa393e7b3d590d45ae72e9af>

[#1226]: /../../issues/1226
[#1230]: /../../pull/1230




## [4.6.2-r3] · 2023-06-15
[4.6.2-r3]: /../../tree/docker/4.6.2-r3

### Security updated

- [Alpine Linux] 3.18.2: <https://github.com/docker-library/official-images/commit/b187a3b64f4b23f4de4aef23b98cef0a128aa8f1>




## [4.6.2-r2] · 2023-06-13
[4.6.2-r2]: /../../tree/docker/4.6.2-r2

### Upgraded

- [Debian Linux] "bookworm": <https://www.debian.org/releases/bookworm>




## [4.6.2-r1] · 2023-05-10
[4.6.2-r1]: /../../tree/docker/4.6.2-r1

### Upgraded

- [Alpine Linux] 3.18: <https://alpinelinux.org/posts/Alpine-3.18.0-released.html>

### Security updated

- [Debian Linux] "bullseye" 20230502: <https://github.com/docker-library/official-images/commit/e4358612aca01fd8aa393e7b3d590d45ae72e9af>




## [4.6.2-r0] · 2023-04-12
[4.6.2-r0]: /../../tree/docker/4.6.2-r0

### Upgraded

- [Coturn] 4.6.2: <https://github.com/coturn/coturn/blob/4.6.2/ChangeLog>
- [Alpine Linux] 3.17: <https://alpinelinux.org/posts/Alpine-3.17.0-released.html>

### Security updated

- [Debian Linux] "bullseye" 20230411: <https://github.com/docker-library/official-images/commit/7697552ea03fcfa76ac2482c8a8ccfb2b594d545>




## [4.6.1-r3] · 2023-03-31
[4.6.1-r3]: /../../tree/docker/4.6.1-r3

### Security updated

- [Alpine Linux] 3.16.5: <https://github.com/docker-library/official-images/commit/d5e1db947991b391f375ef1e8686b884538c1917>
- [Debian Linux] "bullseye" 20230320: <https://github.com/docker-library/official-images/commit/066bc3b863f98325ff211a27301fe1b5a5d51721>




## [4.6.1-r2] · 2023-02-13
[4.6.1-r2]: /../../tree/docker/4.6.1-r2

### Security updated

- [Alpine Linux] 3.16.4: <https://github.com/docker-library/official-images/commit/5819aa56167e9874ef65e35da8277dc71b3ecee6>
- [Debian Linux] "bullseye" 20230208: <https://github.com/docker-library/official-images/commit/0a379d1f4d38dee47df84b07afcf5c26d03cc5a5>




## [4.6.1-r1] · 2023-01-31
[4.6.1-r1]: /../../tree/docker/4.6.1-r1

### Fixed

- Incorrect argument expansion in `docker-entrypoint.sh`. ([#1110])

### Security updated

- [Debian Linux] "bullseye" 20230109: <https://github.com/docker-library/official-images/commit/5e4784af91b60ebae23aab567b6cea3dcdb173a0>

[#1110]: /../../pull/1110




## [4.6.1-r0] · 2022-12-04
[4.6.1-r0]: /../../tree/docker/4.6.1-r0

### Upgraded

- [Coturn] 4.6.1: <https://github.com/coturn/coturn/blob/491b231f80471e63d3f5f3e967a9367e508b2da5/ChangeLog>




## [4.6.0-r1] · 2022-11-16
[4.6.0-r1]: /../../tree/docker/4.6.0-r1

### Added

- Support of `linux/386` platform.

### Security updated

- [Alpine Linux] 3.16.3: <https://github.com/docker-library/official-images/commit/bbdc5719dd50a7d4c112b517b5bd6d7f8d35ceff>
- [Debian Linux] "bullseye" 20221114: <https://github.com/docker-library/official-images/commit/629455d056a9b046c12d4fa65a1006d4b94b5fa5>




## [4.6.0-r0] · 2022-08-13
[4.6.0-r0]: /../../tree/docker/4.6.0-r0

### Upgraded

- [Coturn] 4.6.0: <https://github.com/coturn/coturn/blob/b7b43edd33c21caf18547243649272d2ada1d112/ChangeLog>

### Security updated

- [Debian Linux] "bullseye" 20220912: <https://github.com/docker-library/official-images/commit/80ce239c006d681e7687e1a73777126db94e9959>




## [4.5.2-r14] · 2022-08-10
[4.5.2-r14]: /../../tree/docker/4.5.2-r14

### Security updated

- [Alpine Linux] 3.16.2: <https://github.com/docker-library/official-images/commit/00214788d0150e2bcf2b2f51f786f92addef2478>
- [Debian Linux] "bullseye" 20220801: <https://github.com/docker-library/official-images/commit/ce10f6b60289c0c0b5de6f785528b8725f225a58>




## [4.5.2-r13] · 2022-07-19
[4.5.2-r13]: /../../tree/docker/4.5.2-r13

### Security updated

- [Alpine Linux] 3.16.1: <https://github.com/docker-library/official-images/commit/dcc1108c96213d2f8cca14c23273526913312146>
- [Debian Linux] "bullseye" 20220622: <https://github.com/docker-library/official-images/commit/979b8e278e5d921f1bfddf07d1ab56ab6bb9c3f9>




## [4.5.2-r12] · 2022-05-24
[4.5.2-r12]: /../../tree/docker/4.5.2-r12

### Upgraded

- [Alpine Linux] 3.16: <https://alpinelinux.org/posts/Alpine-3.16.0-released.html>

### Security updated

- [Debian Linux] "bullseye" 20220509: <https://github.com/docker-library/official-images/commit/5e2abb3fc26aa1e16e7e3516580621bef93a64e2>




## [4.5.2-r11] · 2022-04-06
[4.5.2-r11]: /../../tree/docker/4.5.2-r11

### Security updated

- [Alpine Linux] 3.15.4: <https://github.com/docker-library/official-images/commit/1c3c904f7310fa85d2efad018596cc040e00c018>




## [4.5.2-r10] · 2022-03-29
[4.5.2-r10]: /../../tree/docker/4.5.2-r10

### Security updated

- [Alpine Linux] 3.15.3: <https://github.com/docker-library/official-images/commit/e83c8d565978ce1edf1b7bb565484e8cb4419d24>
- [Debian Linux] "bullseye" 20220328: <https://github.com/docker-library/official-images/commit/805cd38af6aec5e5a475c0229c6c1c9831af6124>




## [4.5.2-r9] · 2022-03-25
[4.5.2-r9]: /../../tree/docker/4.5.2-r9

### Security updated

- [Alpine Linux] 3.15.2: <https://github.com/docker-library/official-images/commit/72599f4196000032663a637e542cd23b4dc68936>
- [Debian Linux] "bullseye" 20220316: <https://github.com/docker-library/official-images/commit/1e1bb99db26edc6b8605d83eefc22e1288203a20>




## [4.5.2-r8] · 2021-12-03
[4.5.2-r8]: /../../tree/docker/4.5.2-r8

### Added

- Default TLS ports. ([#860])

[#860]: /../../pull/860




## [4.5.2-r7] · 2021-11-25
[4.5.2-r7]: /../../tree/docker/4.5.2-r7

### Upgraded

- [Alpine Linux] 3.15: <https://alpinelinux.org/posts/Alpine-3.15.0-released.html>




## [4.5.2-r6] · 2021-11-15
[4.5.2-r6]: /../../tree/docker/4.5.2-r6

### Security updated

- [Alpine Linux] 3.14.3: <https://github.com/docker-library/official-images/commit/89298ea1c14b4241dcf3bad1b3092d178ca1ecbc>




## [4.5.2-r5] · 2021-08-29
[4.5.2-r5]: /../../tree/docker/4.5.2-r5

### Upgraded

- [Debian Linux] "bullseye": <https://www.debian.org/releases/bullseye/releasenotes>




## [4.5.2-r4] · 2021-08-28
[4.5.2-r4]: /../../tree/docker/4.5.2-r4

### Security updated

- [Alpine Linux] 3.14.2: <https://github.com/docker-library/official-images/commit/b54effe0cc65795f29752ecc197328a04326a6f2>




## [4.5.2-r3] · 2021-08-09
[4.5.2-r3]: /../../tree/docker/4.5.2-r3

### Security updated

- [Alpine Linux] 3.14.1: <https://github.com/docker-library/official-images/commit/a52e64df36ca65954c6c7f57ad242634e834c73a>




## [4.5.2-r2] · 2021-06-21
[4.5.2-r2]: /../../tree/docker/4.5.2-r2

### Upgraded

- [Alpine Linux] 3.14: <https://alpinelinux.org/posts/Alpine-3.14.0-released.html>




## [4.5.2-r1] · 2021-06-03
[4.5.2-r1]: /../../tree/docker/4.5.2-r1

### Added

- [Prometheus] support with [prometheus-client-c] 0.1.3: <https://github.com/digitalocean/prometheus-client-c/releases/tag/v0.1.3> ([#754])

### Improved

- Use DNS requests to discover external IP address in `detect-external-ip` script. ([#753])

### Fixed

- Incorrect linking with [mongo-c-driver] on [Debian Linux] image.

[#753]: /../../pull/753
[#754]: /../../pull/754




## [4.5.2-r0] · 2021-04-15
[4.5.2-r0]: /../../tree/docker/4.5.2-r0

### Created

- [Coturn] 4.5.2: <https://github.com/coturn/coturn/blob/upstream/4.5.2/ChangeLog> 
- [Alpine Linux] 3.13: <https://alpinelinux.org/posts/Alpine-3.13.0-released.html>
- [Debian Linux] "buster": <https://www.debian.org/releases/buster/releasenotes>
- [mongo-c-driver] 1.17.5 (`debian` only): <https://github.com/mongodb/mongo-c-driver/releases/tag/1.17.5>
- Supported platforms:
    - `linux/amd64`
    - `linux/arm64`
    - `linux/arm/v6`
    - `linux/arm/v7`
    - `linux/ppc64le`
    - `linux/s390x`




[Alpine Linux]: https://www.alpinelinux.org
[Coturn]: https://haraka.github.io
[Debian Linux]: https://www.debian.org
[mongo-c-driver]: https://github.com/mongodb/mongo-c-driver
[Prometheus]: https://prometheus.io
[prometheus-client-c]: https://github.com/digitalocean/prometheus-client-c
